==> AffyTiling_1.10.0.zip: AffyTiling/doc/AffyTiling.R <==
###################################################
### chunk number 1: 
###################################################
#line 42 "AffyTiling.Rnw"
library(AffyTiling)


###################################################
### chunk number 2:  eval=FALSE
###################################################
## #line 48 "AffyTiling.Rnw"
## EXP <- AnalyzeTilingCelFiles(dir(pattern=".cel|.CEL"), "Hs_PromPR_v02-3_NCBIv34.bpmap")


###################################################
### chunk number 3:  eval=FALSE
###################################################
## #line 54 "AffyTiling.Rnw"
## colnames(EXP)
## EXP[1:10,1:5]


###################################################
### chunk number 4:  eval=FALSE
###################################################
## #line 61 "AffyTiling.Rnw"
## EXP <- AnalyzeTilingCelFiles(dir(pattern=".cel|.CEL"), "Hs_PromPR_v02-3_NCBIv34.bpmap", makeUniqueID=FALSE, readProbeSeq=TRUE)


###################################################
### chunk number 5:  eval=FALSE
###################################################
## #line 68 "AffyTiling.Rnw"
## iID <- c(1:3)
## iCHR <- c("chr1", "chr2", "chr3")
## iSTART <- rep(1, 3)
## iEND <- iSTART+1000000
## Einter <- AnalyzeTilingCelFiles(dir(pattern=".cel|.CEL"), "Hs_PromPR_v02-3_NCBIv34.bpmap", iID= iID, iCHR= iCHR, iSTART= iSTART, iEND= iEND)


###################################################
### chunk number 6: 
###################################################
#line 88 "AffyTiling.Rnw"
data(KnownGenes)
colnames(KG)


###################################################
### chunk number 7: 
###################################################
#line 95 "AffyTiling.Rnw"
NearestGenes <- AssociateWithGenes(KG[ , 1], KG[ , 2], KG[ , 3], KG[ , 4], KG[ , 5], Einter[ , 1], Einter[ , 3], (as.integer(Einter[ , 2])+13))
head(NearestGenes)


###################################################
### chunk number 8: 
###################################################
#line 102 "AffyTiling.Rnw"
NearestGenes <- AssociateWithGenes(KG[ , 1], KG[ , 2], KG[ , 3], KG[ , 4], KG[ , 5], Einter[ , 1], Einter[ , 3], (as.integer(Einter[ , 2])+13), D=1000)


###################################################
### chunk number 9: 
###################################################
#line 108 "AffyTiling.Rnw"
GeneOfInterest <- NearestGenes[which(NearestGenes[,2] == "AY358517"),]


###################################################
### chunk number 10: 
###################################################
#line 114 "AffyTiling.Rnw"
lapply(GeneOfInterest[,1], function(x) { Einter[which(Einter[,1] == x),] })[1:10]


###################################################
### chunk number 11: 
###################################################
#line 120 "AffyTiling.Rnw"
ExpSample1 <- as.real( lapply( GeneOfInterest[,1], function(x) { Einter[which(Einter[,1] == x),4] } ) )
GenomicPos <- as.integer(lapply(GeneOfInterest[,1], function(x) { Einter[which(Einter[,1] == x),2] }))
plot(GenomicPos, ExpSample1)


###################################################
### chunk number 12:  eval=FALSE
###################################################
## #line 151 "AffyTiling.Rnw"
## CpG <-read.table("CpG-Table.tsv", header=TRUE, sep="\t")

==> AffyTiling_1.14.0.zip: AffyTiling/doc/AffyTiling.R <==
### R code from vignette source 'AffyTiling.Rnw'

###################################################
### code chunk number 1: AffyTiling.Rnw:41-42
###################################################
library(AffyTiling)


###################################################
### code chunk number 2: AffyTiling.Rnw:47-48 (eval = FALSE)
###################################################
## EXP <- AnalyzeTilingCelFiles(dir(pattern=".cel|.CEL"), "Hs_PromPR_v02-3_NCBIv34.bpmap")


###################################################
### code chunk number 3: AffyTiling.Rnw:53-55 (eval = FALSE)
###################################################
## colnames(EXP)
## EXP[1:10,1:5]


###################################################
### code chunk number 4: AffyTiling.Rnw:60-61 (eval = FALSE)
###################################################
## EXP <- AnalyzeTilingCelFiles(dir(pattern=".cel|.CEL"), "Hs_PromPR_v02-3_NCBIv34.bpmap", makeUniqueID=FALSE, readProbeSeq=TRUE)


###################################################
### code chunk number 5: AffyTiling.Rnw:67-72 (eval = FALSE)
###################################################
## iID <- c(1:3)
## iCHR <- c("chr1", "chr2", "chr3")
## iSTART <- rep(1, 3)
## iEND <- iSTART+1000000
## Einter <- AnalyzeTilingCelFiles(dir(pattern=".cel|.CEL"), "Hs_PromPR_v02-3_NCBIv34.bpmap", iID= iID, iCHR= iCHR, iSTART= iSTART, iEND= iEND)


###################################################
### code chunk number 6: AffyTiling.Rnw:87-89
###################################################
data(KnownGenes)
colnames(KG)


###################################################
### code chunk number 7: AffyTiling.Rnw:94-96
###################################################
NearestGenes <- AssociateWithGenes(KG[ , 1], KG[ , 2], KG[ , 3], KG[ , 4], KG[ , 5], Einter[ , 1], Einter[ , 3], (as.integer(Einter[ , 2])+13))
head(NearestGenes)


###################################################
### code chunk number 8: AffyTiling.Rnw:101-102
###################################################
NearestGenes <- AssociateWithGenes(KG[ , 1], KG[ , 2], KG[ , 3], KG[ , 4], KG[ , 5], Einter[ , 1], Einter[ , 3], (as.integer(Einter[ , 2])+13), D=1000)


###################################################
### code chunk number 9: AffyTiling.Rnw:107-108
###################################################
GeneOfInterest <- NearestGenes[which(NearestGenes[,2] == "AY358517"),]


###################################################
### code chunk number 10: AffyTiling.Rnw:113-114
###################################################
lapply(GeneOfInterest[,1], function(x) { Einter[which(Einter[,1] == x),] })[1:10]


###################################################
### code chunk number 11: AffyTiling.Rnw:119-122
###################################################
ExpSample1 <- as.real( lapply( GeneOfInterest[,1], function(x) { Einter[which(Einter[,1] == x),4] } ) )
GenomicPos <- as.integer(lapply(GeneOfInterest[,1], function(x) { Einter[which(Einter[,1] == x),2] }))
plot(GenomicPos, ExpSample1)


###################################################
### code chunk number 12: AffyTiling.Rnw:150-151 (eval = FALSE)
###################################################
## CpG <-read.table("CpG-Table.tsv", header=TRUE, sep="\t")
